from .main import http,testInternet,setDefaultTestingUrl,setDefaultTimeout

__all__=[
    'http',
    'testInternet',
    'setDefaultTestingUrl',
    'setDefaultTimeout'
]


__version__='1.1.0'
__license__='GPL-2.0 License'
__author__='Tiancheng Jiao'
__url__='https://github.com/jtc1246/easy-http'
__author_email__='jtc1246@outlook.com'
__description__='A very easy http tool'


